#[non_exhaustive]pub struct ExportAssetsResponse {
pub read_time: Option<Timestamp>,
pub output_config: Option<OutputConfig>,
pub output_result: Option<OutputResult>,
/* private fields */
}Expand description
The export asset response. This message is returned by the [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation] method in the returned google.longrunning.Operation.response field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.read_time: Option<Timestamp>Time the snapshot was taken.
output_config: Option<OutputConfig>Output configuration indicating where the results were output to.
output_result: Option<OutputResult>Output result indicating where the assets were exported to. For example, a set of actual Cloud Storage object URIs where the assets are exported to. The URIs can be different from what output_config has specified, as the service will split the output object into multiple ones once it exceeds a single Cloud Storage object limit.
Implementations
Sourceimpl ExportAssetsResponse
impl ExportAssetsResponse
pub fn new() -> Self
Sourcepub fn set_read_time<T>(self, v: T) -> Self
pub fn set_read_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_read_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_read_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_output_config<T>(self, v: T) -> Selfwhere
T: Into<OutputConfig>,
pub fn set_output_config<T>(self, v: T) -> Selfwhere
T: Into<OutputConfig>,
Sets the value of output_config.
Example
use google_cloud_asset_v1::model::OutputConfig;
let x = ExportAssetsResponse::new().set_output_config(OutputConfig::default()/* use setters */);Sourcepub fn set_or_clear_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputConfig>,
pub fn set_or_clear_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputConfig>,
Sets or clears the value of output_config.
Example
use google_cloud_asset_v1::model::OutputConfig;
let x = ExportAssetsResponse::new().set_or_clear_output_config(Some(OutputConfig::default()/* use setters */));
let x = ExportAssetsResponse::new().set_or_clear_output_config(None::<OutputConfig>);Sourcepub fn set_output_result<T>(self, v: T) -> Selfwhere
T: Into<OutputResult>,
pub fn set_output_result<T>(self, v: T) -> Selfwhere
T: Into<OutputResult>,
Sets the value of output_result.
Example
use google_cloud_asset_v1::model::OutputResult;
let x = ExportAssetsResponse::new().set_output_result(OutputResult::default()/* use setters */);Sourcepub fn set_or_clear_output_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputResult>,
pub fn set_or_clear_output_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputResult>,
Sets or clears the value of output_result.
Example
use google_cloud_asset_v1::model::OutputResult;
let x = ExportAssetsResponse::new().set_or_clear_output_result(Some(OutputResult::default()/* use setters */));
let x = ExportAssetsResponse::new().set_or_clear_output_result(None::<OutputResult>);Trait Implementations
Sourceimpl Clone for ExportAssetsResponse
impl Clone for ExportAssetsResponse
Sourcefn clone(&self) -> ExportAssetsResponse
fn clone(&self) -> ExportAssetsResponse
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more