#[non_exhaustive]pub struct FeedOutputConfig {
pub destination: Option<Destination>,
/* private fields */
}Expand description
Output configuration for asset feed destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<Destination>Asset feed destination.
Implementations
Sourceimpl FeedOutputConfig
impl FeedOutputConfig
pub fn new() -> Self
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
ⓘ
use google_cloud_asset_v1::model::PubsubDestination;
let x = FeedOutputConfig::new().set_destination(Some(
google_cloud_asset_v1::model::feed_output_config::Destination::PubsubDestination(PubsubDestination::default().into())));Sourcepub fn pubsub_destination(&self) -> Option<&Box<PubsubDestination>>
pub fn pubsub_destination(&self) -> Option<&Box<PubsubDestination>>
The value of destination
if it holds a PubsubDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_pubsub_destination<T: Into<Box<PubsubDestination>>>(
self,
v: T,
) -> Self
pub fn set_pubsub_destination<T: Into<Box<PubsubDestination>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a PubsubDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
ⓘ
use google_cloud_asset_v1::model::PubsubDestination;
let x = FeedOutputConfig::new().set_pubsub_destination(PubsubDestination::default()/* use setters */);
assert!(x.pubsub_destination().is_some());Trait Implementations
Sourceimpl Clone for FeedOutputConfig
impl Clone for FeedOutputConfig
Sourcefn clone(&self) -> FeedOutputConfig
fn clone(&self) -> FeedOutputConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeedOutputConfig
impl Debug for FeedOutputConfig
Sourceimpl Default for FeedOutputConfig
impl Default for FeedOutputConfig
Sourcefn default() -> FeedOutputConfig
fn default() -> FeedOutputConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for FeedOutputConfig
impl Message for FeedOutputConfig
Sourceimpl PartialEq for FeedOutputConfig
impl PartialEq for FeedOutputConfig
impl StructuralPartialEq for FeedOutputConfig