#[non_exhaustive]pub struct MoveAnalysis {
pub display_name: String,
pub result: Option<Result>,
/* private fields */
}Expand description
A message to group the analysis information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringThe user friendly display name of the analysis. E.g. IAM, organization policy etc.
result: Option<Result>Implementations
Sourceimpl MoveAnalysis
impl MoveAnalysis
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self
pub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self
Sets the value of result.
Note that all the setters affecting result are mutually
exclusive.
Example
ⓘ
use google_cloud_asset_v1::model::MoveAnalysisResult;
let x = MoveAnalysis::new().set_result(Some(
google_cloud_asset_v1::model::move_analysis::Result::Analysis(MoveAnalysisResult::default().into())));Sourcepub fn analysis(&self) -> Option<&Box<MoveAnalysisResult>>
pub fn analysis(&self) -> Option<&Box<MoveAnalysisResult>>
The value of result
if it holds a Analysis, None if the field is not set or
holds a different branch.
Sourcepub fn set_analysis<T: Into<Box<MoveAnalysisResult>>>(self, v: T) -> Self
pub fn set_analysis<T: Into<Box<MoveAnalysisResult>>>(self, v: T) -> Self
Sets the value of result
to hold a Analysis.
Note that all the setters affecting result are
mutually exclusive.
Example
ⓘ
use google_cloud_asset_v1::model::MoveAnalysisResult;
let x = MoveAnalysis::new().set_analysis(MoveAnalysisResult::default()/* use setters */);
assert!(x.analysis().is_some());
assert!(x.error().is_none());Sourcepub fn error(&self) -> Option<&Box<Status>>
pub fn error(&self) -> Option<&Box<Status>>
The value of result
if it holds a Error, None if the field is not set or
holds a different branch.